@@ -19,7 +19,7 @@ use Plack::Response;
 use Web::Solid::Auth::Listener;
 use Web::Solid::Auth::Util;
 
-our $VERSION = "0.5";
+our $VERSION = "0.7";
 
 has webid => (
     is => 'ro' ,
@@ -50,7 +50,7 @@ has client_id => (
 );
 
 sub _build_agent {
-    my $ua = WP::UserAgent->new(agent => "Web::Solid::Auth/$VERSION");
+    my $ua = LWP::UserAgent->new(agent => "Web::Solid::Auth/$VERSION");
     $ua;
 }
 
@@ -580,6 +580,69 @@ Web::Solid::Auth - A Perl Solid Web Client
 
 =head1 SYNOPSIS
 
+    # On the command line
+
+    # Set your default webid
+    export SOLID_WEBID=https://hochstenbach.inrupt.net/profile/card#me
+
+    # Authentication to a pod
+    solid_auth.pl authenticate
+
+    # Get the http headers for a authenticated request
+    solid_auth.pl headers GET https://hochstenbach.inrupt.net/inbox/
+
+    # Act like a curl command and fetch authenticated content
+    solid_auth.pl curl -X GET https://hochstenbach.inrupt.net/inbox/
+
+    # Add some data
+    solid_auth.pl curl -X POST \
+            -H "Content-Type: text/plain" \
+            -d "abc" \
+            https://hochstenbach.inrupt.net/public/
+    
+    # Add a file
+    solid_auth.pl curl -X PUT \
+            -H "Content-Type: application/ld+json" \
+            -d "@myfile.jsonld" \
+            https://hochstenbach.inrupt.net/public/myfile.jsonld 
+
+    # Set a solid base url
+    export SOLID_REMOTE_BASE=https://hochstenbach.inrupt.net
+
+    # List all resources on some Pod path
+    solid_auth.pl list /public/
+
+    # Get some data
+    solid_auth.pl get /inbox/
+
+    # Post some data
+    solid_auth.pl post /inbox/ myfile.jsonld 
+
+    # Put some data
+    solid_auth.pl put /public/myfile.txt myfile.txt 
+
+    # Create a folder
+    solid_auth.pl put /public/mytestfolder/
+
+    # Delete some data
+    solid_auth.pl delete /public/myfile.txt
+
+    # Mirror a resource, container or tree
+    solid_auth.pl mirror /public/ ./my_copy
+
+    # Upload a directory to the pod
+    #  Add the -x option to do it for real (only a test without this option)
+    solid_auth.pl -r upload /data/my_copy /public/
+
+    # Clean all files in a container
+    #  Add the -x option to do it for real (only a test without this option)
+    solid_auth.pl --keep clean /demo/
+
+    # Clean a complete container 
+    #  Add the -x option to do it for real (only a test without this option)
+    solid_auth.pl -r clean /demo/
+
+    # In a perl program
     use Web::Solid::Auth;
     use Web::Solid::Auth::Listener;
 
@@ -683,7 +746,8 @@ L<solid_auth.pl>
 =head1 INSPIRATION
 
 This was very much inspired by the Python solid-flask code by
-Rai L<http://agentydragon.com> at L<https://gitlab.com/agentydragon/solid-flask>
+Rai L<http://agentydragon.com> at L<https://gitlab.com/agentydragon/solid-flask>,
+and Jeff Zucker's <https://github.com/jeff-zucker> Solid-Shell at L<https://www.npmjs.com/package/solid-shell>.
 
 =head1 COPYRIGHT AND LICENSE
 
